@@ -1,4 +1,11 @@
-"""init pyezvizapi."""
+"""Top-level package for the Ezviz Cloud API helpers.
+
+This package provides a small, typed API surface around Ezviz cloud
+endpoints tailored for Home Assistant and light scripting. The
+submodules contain focused functionality (client, camera/light models,
+MQTT push, CAS, utilities) and this package exports the most useful
+symbols for convenient imports.
+"""
 
 from .camera import EzvizCamera
 from .cas import EzvizCAS
@@ -28,7 +35,8 @@ from .exceptions import (
     PyEzvizError,
 )
 from .light_bulb import EzvizLightBulb
-from .mqtt import MQTTClient
+from .models import EzvizDeviceRecord, build_device_records_map
+from .mqtt import EzvizToken, MQTTClient, MqttData, ServiceUrls
 from .test_cam_rtsp import TestRTSPAuth
 
 __all__ = [
@@ -46,16 +54,21 @@ __all__ = [
     "EzvizCAS",
     "EzvizCamera",
     "EzvizClient",
+    "EzvizDeviceRecord",
     "EzvizLightBulb",
+    "EzvizToken",
     "HTTPError",
     "IntelligentDetectionSmartApp",
     "InvalidHost",
     "InvalidURL",
     "MQTTClient",
     "MessageFilterType",
+    "MqttData",
     "NightVisionMode",
     "PyEzvizError",
+    "ServiceUrls",
     "SoundMode",
     "SupportExt",
     "TestRTSPAuth",
+    "build_device_records_map",
 ]
